@@ -55,6 +55,11 @@
 #'   `"text-light"`) to customize the background/foreground colors.
 #' @param fill Whether to allow the value box to grow/shrink to fit a fillable
 #'   container with an opinionated height (e.g., `page_fillable()`).
+#' @param max_height The maximum height of the `value_box()` or the showcase
+#'   area when used in a `showcase_layout_*()` function. Can be any valid [CSS
+#'   unit][htmltools::validateCssUnit] (e.g., `max_height="200px"`).
+#' @param min_height The minimum height of the values box. Can be any valid [CSS
+#'   unit][htmltools::validateCssUnit] (e.g., `min_height="200px"`).
 #' @inheritParams card
 #' @param theme_color `r lifecycle::badge("deprecated")` Use `theme` instead.
 #'
@@ -94,8 +99,10 @@ value_box <- function(
   theme = NULL,
   height = NULL,
   max_height = NULL,
+  min_height = NULL,
   fill = TRUE,
   class = NULL,
+  id = NULL,
   theme_color = deprecated()
 ) {
   dots <- separate_arguments(...)
@@ -155,9 +162,11 @@ value_box <- function(
       class,
       if (!is.null(showcase)) showcase_layout$class
     ),
+    id = id,
     full_screen = full_screen,
     height = height,
     max_height = max_height,
+    min_height = min_height,
     fill = fill,
     style = css(
       color = theme$fg,
@@ -227,9 +236,9 @@ new_value_box_theme <- function(class = NULL, bg = NULL, fg = NULL) {
 #'     Accepted values in the second category are `"auto"`, `"min-content"`,
 #'     `"max-content"`, a fractional unit (e.g. `2fr`), or a `minmax()` function
 #'     (e.g., `minmax(100px, 1fr)`).
-#' @param max_height,max_height_full_screen A proportion (i.e., a number between
+#' @param max_height_full_screen A proportion (i.e., a number between
 #'   0 and 1) or any valid [CSS unit][htmltools::validateCssUnit] defining the
-#'   showcase max_height.
+#'   showcase `max_height` in a full screen card.
 #'
 #' @export
 #' @rdname value_box
